@@ -43,8 +43,8 @@
 #define TITRAQ_DEFHOME          "."
 #define TITRAQ_PREFUSER         "user"
 #define TITRAQ_DEFUSER          "username"
-#define TITRAQ_PREFASFILE       "asfile"
-#define TITRAQ_DEFASFILE        "~/.as/events.as"
+#define TITRAQ_PREFASDIR        "asdir"
+#define TITRAQ_DEFASDIR         "~/.as/"
 #define TITRAQ_PREFACCOUNTS     "accounts"
 #define TITRAQ_DEFACCOUNTS      "~/.as/accounts"
 #define TITRAQ_PREFSTYLE        "uistyle"
@@ -150,10 +150,17 @@
 #define TITRAQ_ENVUSERNAME      "USER"
 #define TITRAQ_ENVHOMEDIR       "HOME"
 
+// Falsified incoming ORB initilization arguments
+#define TITRAQ_ORBINIT          "-ORBGIOPVersion 1.2 -ORBIIOPVersion 1.2 -ORBInitRef"
+#define TITRAQ_COSSPART1        "NameService=corbaloc::"
+#define TITRAQ_COSSPART2        "/NameService"
+#define TITRAQ_SOAPSPACE        "http://soap.europalab.com/asdb"
+#define TITRAQ_PREFIXHTTP       "http://"
+
 // Style string constants
 #define TITRAQ_STRCDE           "CDE"
 #define TITRAQ_STRSGI           "SGI"
-#define TITRAQ_STRMOTIF         "Motfi"
+#define TITRAQ_STRMOTIF         "Motif"
 #define TITRAQ_STRMPLUS         "MotifPlus"
 #define TITRAQ_STRPLAT          "Platinum"
 #define TITRAQ_STRMSOFT         "Windows"
