@@ -29,6 +29,10 @@
 //  tidatops.cpp: ISO C++ implementation
 //
 
+// System headers
+#include <map>
+#include <string>
+
 // Qt general headers
 #include <qregexp.h>            // Portable regular expressions
 #include <qdatetime.h>
@@ -72,7 +76,13 @@ void Titraqform::loadAccounts(QFile &Fileobj)
 //
 void Titraqform::loadAccounts(QTextStream &Tstream)
 {
-    QString Line; // Used for linewise editing and whitespace eating
+    using namespace std;                // Needed for hash tables with hmap
+    map<string, int> Hashnames;         // Hashtable for storing names
+    map<int, string> Hashnums;          // Hashtable for storing repetitions
+    map<string, int>::iterator Nameiter; // The hashtable name iterator
+    map<int, string>::iterator Numiter;  // The hashtable number iterator
+
+    QString Line;           // Used for linewise editing and whitespace eating
 
     // Eat lines until reading the start accounts token
     while (!Line.startsWith(trUtf8("%!AS-ACCOUNTS")) && !Tstream.atEnd()) {
@@ -99,7 +109,8 @@ void Titraqform::loadAccounts(QTextStream &Tstream)
 
         if (Temp == QString(QChar('R'))) {  // Copy the account field
             Asline >> Temp;                 // to temporary for transfer
-            *m_pTaskentries << Temp;        // to internal account bank
+            string Convstring = Temp;       // Convert to string (can't cast?)
+            Hashnames[Convstring] += Hashnames[Convstring];
         }
 
         Line = QString(""); // Clear line for next round
@@ -110,6 +121,22 @@ void Titraqform::loadAccounts(QTextStream &Tstream)
                 Line = QString("");
         }
     }
+
+//    Hashnames.insert(map<string, int>::value_type((string)QString, int));
+    for (Nameiter = Hashnames.begin(); Nameiter != Hashnames.end(); Nameiter++)
+        Hashnums[Nameiter->second] += Nameiter->first + '\n';
+
+// FIXME: Put this in loadData, to load custom and most used task names before
+// FIXME: default listings are sorted and inserted
+    for (Numiter = Hashnums.begin(); Numiter != Hashnums.end(); Numiter++) {
+
+        // Count the number of lines of sorted task names
+        int nNumlines = QString(Numiter->second).contains('\n');
+
+        // Iterate through the lines of task names, feeding them into the menu
+        for (int nIter = 0; nIter < nNumlines; nIter++)
+            *m_pTaskentries << QString(Numiter->second).section('\n', nIter, nIter);
+    }
 }
 
 //
@@ -262,7 +289,9 @@ void Titraqform::loadData(QTextStream &Tstream)
         if (!Account.isEmpty()) {
             QTableItem *pOld = m_pMaintable->item(nIter, TITRAQ_IDXTASK);
             delete(pOld);   // Get rid of the old before going with the new
-            m_pMaintable->setItem(nIter, TITRAQ_IDXTASK, new RtTableItem(m_pMaintable, QTableItem::WhenCurrent, Account));
+            RtTableItem *pSwapitem = new RtTableItem(m_pMaintable, QTableItem::WhenCurrent, Account);
+            pSwapitem->setAlignment(AlignLeft | AlignVCenter);
+            m_pMaintable->setItem(nIter, TITRAQ_IDXTASK, pSwapitem);
         }
         else
             bValid = false;
@@ -524,7 +553,9 @@ void Titraqform::setRowdata(QString &Rowdata) const
         // Change out old item and replace with new task data
         pItem = m_pMaintable->item(nCurrentrow + nIter, TITRAQ_IDXTASK);
         delete(pItem);  // Get rid of the old before going with the new
-        m_pMaintable->setItem(nCurrentrow + nIter, TITRAQ_IDXTASK, new RtTableItem(m_pMaintable, QTableItem::WhenCurrent, Task));
+        RtTableItem *pSwapitem = new RtTableItem(m_pMaintable, QTableItem::WhenCurrent, Task);
+        pSwapitem->setAlignment(AlignLeft | AlignVCenter);
+        m_pMaintable->setItem(nCurrentrow + nIter, TITRAQ_IDXTASK, pSwapitem);
 
         // Continue with field processing business as usual
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXREMARK, Remark.simplifyWhiteSpace());
