@@ -205,7 +205,7 @@ public:
     QAction     *m_pAddrowact,    *m_pDelrowact;
     QAction     *m_pRefreshact,   *m_pCutact;
     QAction     *m_pCopyact,      *m_pPasteact;
-    QAction     *m_pSynciiopact,  *m_pSyncsoapact;
+    QAction     *m_pSyncact;
 
     // Table, cells, and entries in package layout
     TiTable     *m_pMaintable;
