@@ -133,18 +133,18 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     m_pGeninner->addWidget(m_pAcctlabel, 0, 0);
     m_pAcctline = new QLineEdit(m_pGenbox, "Accountline");
     m_pGeninner->addWidget(m_pAcctline, 0, 1);
-    m_pEventlabel = new QLabel(m_pGenbox, "Evntfilelabel");
+    m_pEventlabel = new QLabel(m_pGenbox, "Evntdirlabel");
     m_pGeninner->addWidget(m_pEventlabel, 1, 0);
     m_pEventline = new QLineEdit(m_pGenbox, "Eventline");
     m_pGeninner->addWidget(m_pEventline, 1, 1);
-    m_pUserlabel = new QLabel(m_pGenbox, "Userlabel");
-    m_pGeninner->addWidget(m_pUserlabel, 2, 0);
-    m_pUserline = new QLineEdit(m_pGenbox, "Userline");
-    m_pGeninner->addWidget(m_pUserline, 2, 1);
     m_pHomelabel = new QLabel(m_pGenbox, "Homelabel");
-    m_pGeninner->addWidget(m_pHomelabel, 3, 0);
+    m_pGeninner->addWidget(m_pHomelabel, 2, 0);
     m_pHomeline = new QLineEdit(m_pGenbox, "Homeline");
-    m_pGeninner->addWidget(m_pHomeline, 3, 1);
+    m_pGeninner->addWidget(m_pHomeline, 2, 1);
+    m_pUserlabel = new QLabel(m_pGenbox, "Userlabel");
+    m_pGeninner->addWidget(m_pUserlabel, 3, 0);
+    m_pUserline = new QLineEdit(m_pGenbox, "Userline");
+    m_pGeninner->addWidget(m_pUserline, 3, 1);
     m_pGenboxlay->addLayout(m_pGeninner);
 
     m_pGenlayout->addWidget(m_pGenbox);
@@ -242,11 +242,11 @@ void Prefpanel::textChange()
 
     m_pGenbox->setTitle(tr("File and directory paths", "Comment for Genbox"));
     m_pAcctlabel->setText(tr("Accounts path", "Comment for Acctlabel"));
-    m_pEventlabel->setText(tr("Events path", "Comment for Eventlabel"));
+    m_pEventlabel->setText(tr("Events directory", "Comment for Eventlabel"));
     m_pUserlabel->setText(tr("User name", "Comment for Userlabel"));
     m_pHomelabel->setText(tr("Home directory", "Comment for Homelabel"));
     QToolTip::add(m_pAcctline, tr("The accounts file pathname", "Comment for toolTip Acctline"));
-    QToolTip::add(m_pEventline, tr("The events file pathname", "Comment for toolTip Eventline"));
+    QToolTip::add(m_pEventline, tr("The default events directory", "Comment for toolTip Eventline"));
     QToolTip::add(m_pUserline, tr("The user name", "Comment for toolTip Userline"));
     QToolTip::add(m_pHomeline, tr("The home directory", "Comment for toolTip Homeline"));
 
