@@ -110,6 +110,8 @@ public:
     void setSoaphost(const QString &kInstr)  {m_pSoapline->setText(kInstr);};
     void setBackon(const bool &kbEnable = true)   {m_pBackupcheck->setChecked(kbEnable);};
     void setExtendon(const bool &kbEnable = true) {m_pExtendcheck->setChecked(kbEnable);};
+    void lockCorba(const bool &kbLock = true) {m_pCorbacheck->setEnabled(!kbLock);};
+    void lockSoap(const bool &kbLock = true) {m_pSoapcheck->setEnabled(!kbLock);};
     void setCorbaon(const bool &kbEnable = true) {
         m_pCorbaline->setEnabled(kbEnable);
         m_pCorbacheck->setChecked(kbEnable);
