@@ -31,6 +31,7 @@
 
 // system headers
 #include <memory>
+#include <cstring>
 
 // Qt headers
 #include <qfiledialog.h>
@@ -39,6 +40,14 @@
 #include <qmenudata.h>
 #include <qdatastream.h>
 
+// Qt style headers
+#include <qcdestyle.h>
+#include <qsgistyle.h>
+#include <qmotifstyle.h>
+#include <qmotifplusstyle.h>
+#include <qplatinumstyle.h>
+#include <qwindowsstyle.h>
+
 // User interface
 #include "as_gui.h"             // Main classes
 #include "as_except.h"          // Exception classes
@@ -226,12 +235,10 @@ void Titraqform::addEntry(int nRows)
         m_pRemark->setEnabled(true);
 
         // And optionally the RPC actions, too
-#ifdef HAVE_MICO
-        m_pSynciiopact->setEnabled(true);
-#endif // HAVE_MICO
-#ifdef HAVE_ESOAP
-        m_pSyncsoapact->setEnabled(true);
-#endif // HAVE_ESOAP
+#if defined HAVE_MICO || defined HAVE_ESOAP
+        m_pSyncact->setEnabled(m_pPrefs->getBool(TITRAQ_PREFCORBON, TITRAQ_DEFCORBON)
+            | m_pPrefs->getBool(TITRAQ_PREFSOAPON, TITRAQ_DEFSOAPON));
+#endif // HAVE_MICO || defined HAVE_ESOAP
     }
 }
 
@@ -286,12 +293,9 @@ void Titraqform::delEntry(int nRows)
         m_pRemark->setEnabled(false);
 
         // And optionally dim the RPC actions
-#ifdef HAVE_MICO
-        m_pSynciiopact->setEnabled(false);
-#endif // HAVE_MICO
-#ifdef HAVE_ESOAP
-        m_pSyncsoapact->setEnabled(false);
-#endif // HAVE_ESOAP
+#if defined HAVE_MICO || defined HAVE_ESOAP
+        m_pSyncact->setEnabled(false);
+#endif // HAVE_MICO || defined HAVE_ESOAP
     }
 }
 
@@ -393,7 +397,7 @@ void Titraqform::openDoc(void)
 //
     if (!m_pMaintable->isDirty() || nResult == 1) { // Check modification state
         // Make sure we correctly get the name of the default file to open
-        QString Openas = m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
+        QString Openas = m_pPrefs->getString(TITRAQ_PREFASDIR, TITRAQ_DEFASDIR);
         if (Openas.startsWith(TITRAQ_HOMEDIRTOK))
             Openas = QDir::homeDirPath() + Openas.remove(0, QString(TITRAQ_HOMEDIRTOK).length() - 1);
 
@@ -450,7 +454,8 @@ void Titraqform::saveFile(void)
         }
 
         Filevents.setName(Fname);   // Construct a file to write
-        Filevents.makeBackup();     // Back up to filename.bak
+        if (m_pPrefs->getBool(TITRAQ_PREFBAKON, TITRAQ_DEFBAKON))
+            Filevents.makeBackup(); // Back up to filename.bak
         this->saveData(Filevents);  // Pass to helper method
     }
     catch (Genexcept& Genex) {
@@ -470,7 +475,7 @@ void Titraqform::saveAs(void)
     int nResult = 0; // For checking user's answer
 
     // Make sure we correctly get the name of the default file to open
-    QString Openas = m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
+    QString Openas = m_pPrefs->getString(TITRAQ_PREFASDIR, TITRAQ_DEFASDIR);
     if (Openas.startsWith(TITRAQ_HOMEDIRTOK))
         Openas = QDir::homeDirPath() + Openas.remove(0, QString(TITRAQ_HOMEDIRTOK).length() - 1);
 
@@ -492,9 +497,12 @@ void Titraqform::saveAs(void)
             }
         }
         else {
-            QString Extension = TITRAQ_FEXTENSION;  // Logic to handle
-            if (!Filestring.endsWith(Extension))    // AS file extension
-                Filestring += Extension;            // insertion
+            // Conditionally use a unique extension like '.as' if user prefers
+            if (m_pPrefs->getBool(TITRAQ_PREFEXTENDON, TITRAQ_DEFEXTENDON)) {
+                QString Extension = TITRAQ_FEXTENSION;  // Logic to handle
+                if (!Filestring.endsWith(Extension))    // AS file extension
+                    Filestring += Extension;            // insertion
+            }
             this->setFilename(Filestring);  // Set filename of object first
             this->saveFile();               // Finish by calling the save action
         }
@@ -513,7 +521,7 @@ void Titraqform::saveName(void)
     int nResult = 0; // For checking user's answer
 
     // Make sure we correctly get the name of the default file to open
-    QString Openas = m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
+    QString Openas = m_pPrefs->getString(TITRAQ_PREFASDIR, TITRAQ_DEFASDIR);
     if (Openas.startsWith(TITRAQ_HOMEDIRTOK))
         Openas = QDir::homeDirPath() + Openas.remove(0, QString(TITRAQ_HOMEDIRTOK).length() - 1);
 
@@ -536,9 +544,13 @@ void Titraqform::saveName(void)
                 }
             }
             else {
-                QString Extension = TITRAQ_FEXTENSION;  // Logic to handle
-                if (!Filestring.endsWith(Extension))    // AS file extension
-                    Filestring += Extension;            // insertion
+
+                // Conditionally use a unique extension like '.as' if user prefers
+                if (m_pPrefs->getBool(TITRAQ_PREFEXTENDON, TITRAQ_DEFEXTENDON)) {
+                    QString Extension = TITRAQ_FEXTENSION;  // Logic to handle
+                    if (!Filestring.endsWith(Extension))    // AS file extension
+                        Filestring += Extension;            // insertion
+                }
                 this->setFilename(Filestring);  // Set filename of object first
                 nResult = 0;                    // Reset our loop control
                 this->saveFile();               // Finish by calling the save action
@@ -1114,13 +1126,23 @@ void Titraqform::configPrefs(void)
 
     // Set default values to appear in initialized panel widgets
     pUserpanel->setAccounts(m_pPrefs->getString(TITRAQ_PREFACCOUNTS, TITRAQ_DEFACCOUNTS));
-    pUserpanel->setEvents(m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE));
+    pUserpanel->setEvents(m_pPrefs->getString(TITRAQ_PREFASDIR, TITRAQ_DEFASDIR));
     pUserpanel->setUser(m_pPrefs->getString(TITRAQ_PREFUSER, TITRAQ_DEFUSER));
     pUserpanel->setHome(m_pPrefs->getString(TITRAQ_PREFHOME, TITRAQ_DEFHOME));
     pUserpanel->setCorbahost(m_pPrefs->getString(TITRAQ_PREFCORBHOST, TITRAQ_DEFCORBHOST));
     pUserpanel->setSoaphost(m_pPrefs->getString(TITRAQ_PREFSOAPHOST, TITRAQ_DEFSOAPHOST));
+#ifdef HAVE_MICO
     pUserpanel->setCorbaon(m_pPrefs->getBool(TITRAQ_PREFCORBON, TITRAQ_DEFCORBON));
+#else
+    pUserpanel->setCorbaon(false);
+    pUserpanel->lockCorba();
+#endif
+#ifdef HAVE_ESOAP
     pUserpanel->setSoapon(m_pPrefs->getBool(TITRAQ_PREFSOAPON, TITRAQ_DEFSOAPON));
+#else
+    pUserpanel->setSoapon(false);
+    pUserpanel->lockSoap();
+#endif
     pUserpanel->setBackon(m_pPrefs->getBool(TITRAQ_PREFBAKON, TITRAQ_DEFBAKON));
     pUserpanel->setExtendon(m_pPrefs->getBool(TITRAQ_PREFEXTENDON, TITRAQ_DEFEXTENDON));
 
@@ -1152,7 +1174,7 @@ void Titraqform::configPrefs(void)
     // Modal panel handler
     if (pUserpanel->exec() == QDialog::Accepted) {
         m_pPrefs->setString(TITRAQ_PREFACCOUNTS, pUserpanel->getAccounts());
-        m_pPrefs->setString(TITRAQ_PREFASFILE, pUserpanel->getEvents());
+        m_pPrefs->setString(TITRAQ_PREFASDIR, pUserpanel->getEvents());
         m_pPrefs->setString(TITRAQ_PREFUSER, pUserpanel->getUser());
         m_pPrefs->setString(TITRAQ_PREFHOME, pUserpanel->getHome());
         m_pPrefs->setString(TITRAQ_PREFCORBHOST, pUserpanel->getCorbahost());
@@ -1162,19 +1184,38 @@ void Titraqform::configPrefs(void)
         m_pPrefs->setBool(TITRAQ_PREFBAKON, pUserpanel->getBackon());
         m_pPrefs->setBool(TITRAQ_PREFEXTENDON, pUserpanel->getExtendon());
 
+        // Dim the lights if no RPC transports are available
+        if (this->isOpen())
+            m_pSyncact->setEnabled(m_pPrefs->getBool(TITRAQ_PREFCORBON, TITRAQ_DEFCORBON)
+                | m_pPrefs->getBool(TITRAQ_PREFSOAPON, TITRAQ_DEFSOAPON));
+        else
+            m_pSyncact->setEnabled(false);
+
         // Get the selected style which can be more complicated due to mapping...
-        if (pUserpanel->getStyle() == TITRAQ_STRCDE)
+        if (pUserpanel->getStyle() == TITRAQ_STRCDE) {
             m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE);
-        else if (pUserpanel->getStyle() == TITRAQ_STRSGI)
+            qApp->setStyle(new QCDEStyle);
+        }
+        else if (pUserpanel->getStyle() == TITRAQ_STRSGI) {
             m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLESGI);
-        else if (pUserpanel->getStyle() == TITRAQ_STRMOTIF)
+            qApp->setStyle(new QSGIStyle);
+        }
+        else if (pUserpanel->getStyle() == TITRAQ_STRMOTIF) {
             m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLEMOTIF);
-        else if (pUserpanel->getStyle() == TITRAQ_STRMPLUS)
+            qApp->setStyle(new QMotifStyle);
+        }
+        else if (pUserpanel->getStyle() == TITRAQ_STRMPLUS) {
             m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLEMPLUS);
-        else if (pUserpanel->getStyle() == TITRAQ_STRPLAT)
+            qApp->setStyle(new QMotifPlusStyle);
+        }
+        else if (pUserpanel->getStyle() == TITRAQ_STRPLAT) {
             m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLEPLAT);
-        else if (pUserpanel->getStyle() == TITRAQ_STRMSOFT)
+            qApp->setStyle(new QPlatinumStyle);
+        }
+        else if (pUserpanel->getStyle() == TITRAQ_STRMSOFT) {
             m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLEMSOFT);
+            qApp->setStyle(new QWindowsStyle);
+        }
         else // My personal favourite ;-)
             m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE);
     }
@@ -1547,9 +1588,12 @@ void Titraqform::genReport(void)
 void Titraqform::syncIiop(void)
 {
 #ifdef HAVE_MICO
-    int nNada = 0;          // Some false parameters
-    char **ppcNada = NULL;  // to fake out the ORB
-    CORBA::ORB_var Orb;     // The ORB
+    // Short circuit if user has disabled CORBA transmission in prefs
+    if (!m_pPrefs->getBool(TITRAQ_PREFCORBON, TITRAQ_DEFCORBON))
+        return;
+
+    char **ppcInargv = NULL;    // Parameters to the ORB
+    CORBA::ORB_var Orb;         // The ORB iself
 
     CORBA::Object_var Nameobj;      // Name service reference
     CosNaming::NamingContext_var Namectx; // COSS ns context
@@ -1559,9 +1603,32 @@ void Titraqform::syncIiop(void)
     Asdatabase_var Asdbase;         // Casted object to ASDB
     Astuple Singlerow;              // A single row of AS data
 
+    QString *pOrbargv = new QString(TITRAQ_ORBINIT);
+    int nCount = pOrbargv->contains(' ');
+    int nNamesize = 0;
+
+    // Build a false incoming argv with which we initialize the ORB
+    ppcInargv = new char *[nCount + 3]; // 3 = arg0 + last section + COSS host
+    *ppcInargv = new char[strlen(*qApp->argv() + 2)]; // For cmd name
+    strcpy(ppcInargv[0], *qApp->argv());              // Copy cmd name
+    for (int nIter = 0; nIter <= nCount; nIter++) {
+        QString Section = pOrbargv->section(' ', nIter, nIter);
+        ppcInargv[nIter + 1] = new char[strlen(Section.ascii() + 2)];
+        strcpy(ppcInargv[nIter + 1], Section.ascii());
+    }
+
+    // Build the single string COSS naming host name with associated port number
+    *pOrbargv = TITRAQ_COSSPART1
+              + m_pPrefs->getString(TITRAQ_PREFCORBHOST, TITRAQ_DEFCORBHOST)
+              + TITRAQ_COSSPART2;
+    nNamesize = strlen(pOrbargv->ascii());
+    ppcInargv[nCount + 2] = new char[nNamesize];
+    strcpy(ppcInargv[nCount + 2], pOrbargv->ascii());
+
     try {
         // Initialization of the ORB and COSS naming service
-        Orb = CORBA::ORB_init(nNada, ppcNada, "mico-local-orb");
+        nCount = nCount + 3; // Raise the count to include app, last sec, COSS
+        Orb = CORBA::ORB_init(nCount, ppcInargv, "mico-local-orb");
         Nameobj = Orb->resolve_initial_references("NameService");
         Namectx = CosNaming::NamingContext::_narrow(Nameobj);
         if (CORBA::is_nil(Namectx)) { // Verify sanity
@@ -1569,6 +1636,12 @@ void Titraqform::syncIiop(void)
             qWarning("Could not find the COSS naming service\n");
         }
 
+        // Clean up our dynamically allocated array
+        for (int nIter = 0; nIter < nCount; nIter++)
+            delete ppcInargv[nIter];
+        delete ppcInargv; // Free the array itself
+        delete pOrbargv;  // Free the intermediate string
+
         // Prepare the COSS name request
         Cosname.length(1);
         Cosname[0].id = CORBA::string_dup("Asdatabase");
@@ -1652,32 +1725,42 @@ void Titraqform::syncIiop(void)
 void Titraqform::syncSoap(void)
 {
 #ifdef HAVE_ESOAP
+    // Short circuit if user has disabled SOAP transmission in prefs
+    if (!m_pPrefs->getBool(TITRAQ_PREFSOAPON, TITRAQ_DEFSOAPON))
+        return;
+
     USING_EASYSOAP_NAMESPACE
 
     try {
-        const char *pSpace    = "http://soap.europalab.com/asdb";
-        const char *pEndpoint = "http://www.europalab.com/cgi-bin/asdbserv";
-        SOAPProxy Proxy(pEndpoint);
-        SOAPMethod Logmeth("Log", pSpace);  // SOAP remote method name
+        SOAPMethod Logmeth("Log", TITRAQ_SOAPSPACE); // SOAP namespace
         SOAPString Clistr;                  // Outgoing parameter to marshall
         int nCrc;                           // SOAP unmarshalled return value
 
-        // A quasi diff summary to transmit to the server
-        QString Syncthis;
-        int nRow = m_pMaintable->currentRow();
-        Syncthis += m_pMaintable->text(nRow, TITRAQ_IDXUSER);
-        for (int nIter = TITRAQ_IDXUSER + 1; nIter < TITRAQ_IDXTAIL; nIter++)
-            Syncthis += ' ' + m_pMaintable->text(nRow, nIter);
+        // Build the single string SOAP end point which look like this:
+        //   "http://www.europalab.com/cgi-bin/asdbserv"
+        QString Endpoint;
+        Endpoint = TITRAQ_PREFIXHTTP + m_pPrefs->getString(TITRAQ_PREFSOAPHOST, TITRAQ_DEFSOAPHOST);
+        SOAPProxy Proxy(Endpoint.ascii());
 
-        Clistr = Syncthis;                          // Build RPC parameter
-        Logmeth.AddParameter("Tuple") << Clistr;    // Prepare for marshalling
-        const SOAPResponse &Logresp = Proxy.Execute(Logmeth);
-        Logresp.GetReturnValue() >> nCrc;
+        // Fill account log object(s) to marshall and transmit
+        QTableSelection Select = m_pMaintable->selection(0);    // Capture selected rows
+        int nTotal = Select.bottomRow() - Select.topRow() + 1;  // Total rows selected
+
+        // Iterate through the selection of row entries to transmit
+        for (int nRowiter = 0; nRowiter < nTotal; nRowiter++) {
+            QString Syncthis = m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXUSER);
+            for (int nColiter = TITRAQ_IDXUSER + 1; nColiter < TITRAQ_IDXTAIL; nColiter++)
+                Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, nColiter);
+            Clistr = Syncthis;                          // Build RPC parameter
+            Logmeth.AddParameter("Tuple") << Clistr;    // Prepare for marshalling
+            const SOAPResponse &Logresp = Proxy.Execute(Logmeth);
+            Logresp.GetReturnValue() >> nCrc;
+        }
         m_pStatbar->message(trUtf8("Successful transmission, CRC returned %1").arg(nCrc));
     }
     catch (SOAPException& Soapex) { // Announce the exception we received
         m_pStatbar->message(trUtf8("Caught SOAP exception: %1").arg(Soapex.What().Str()));
-        qDebug("Caught SOAP exception: %s\n", Soapex.What().Str());
+        qDebug("Caught SOAP exception: %s", Soapex.What().Str());
     }
     catch (...) {
         qDebug("Caught unknown exception\n");
